==> haskell-x11-xft-0.3.1-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 X11-xft
version:              0.3.1
visibility:           public
id:                   X11-xft-0.3.1-1OghTDluFZq4VGwVWpbc8I
key:                  X11-xft-0.3.1-1OghTDluFZq4VGwVWpbc8I
license:              LicenseRef-LGPL
maintainer:           clemens@endorphin.org
author:               Clemens Fruhwirth
synopsis:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts

description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts

category:             Graphics
abi:                  73f54eda877b4533dd10fdc6ebcb37f8
exposed:              True
exposed-modules:      Graphics.X11.Xft Graphics.X11.Xrender
import-dirs:          /usr/lib/ghc-8.10.2/site-local/X11-xft-0.3.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/X11-xft-0.3.1
hs-libraries:         HSX11-xft-0.3.1-1OghTDluFZq4VGwVWpbc8I
extra-libraries:      Xft
include-dirs:
    /usr/include/freetype2 /usr/include/libpng16 /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include

depends:
    X11-1.9.2-UopGvyQXKg1QknKZFzanD base-4.14.1.0
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R

haddock-interfaces:   /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html:         /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-xft-0.3.1-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 X11-xft
version:              0.3.1
visibility:           public
id:                   X11-xft-0.3.1-GoEseyoTWfKEcYD54YuXmi
key:                  X11-xft-0.3.1-GoEseyoTWfKEcYD54YuXmi
license:              LicenseRef-LGPL
maintainer:           clemens@endorphin.org
author:               Clemens Fruhwirth
synopsis:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts

description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts

category:             Graphics
abi:                  7a286d4aa7af2976329bb6f2830d8cdf
exposed:              True
exposed-modules:      Graphics.X11.Xft Graphics.X11.Xrender
import-dirs:          /usr/lib/ghc-8.10.2/site-local/X11-xft-0.3.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/X11-xft-0.3.1
hs-libraries:         HSX11-xft-0.3.1-GoEseyoTWfKEcYD54YuXmi
extra-libraries:      Xft
include-dirs:
    /usr/include/freetype2 /usr/include/libpng16 /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include

depends:
    X11-1.9.2-EanA4Expv66KGudq3daBEX base-4.14.1.0
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R

haddock-interfaces:   /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html:         /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
